Changelog
=========

0.4 (2015-08-21)
----------------------

-  Flask bindings
-  xmlrpclib client bindings
-  Filtered parameters in sqlalchemy binding
-  Implement exponential backoff on connection


0.3 (2015-02-16)
----------------

-  Make the service name configurable for pyramid application


0.2 (2015-02-16)
----------------

-  Keep @trace usable when zipkin is not configured


0.1 (2015-02-16)
----------------

-  Initial version
